==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/SERVICELIFEUSAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SERVICELIFEUSAGEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SERVICELIFEUSAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETCLASSDEFINITIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICELIFEUSAGEID_Type", propOrder = {
    "uomid",
    "assetclassdefinitionid"
})
public class SERVICELIFEUSAGEID_Type {

    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "ASSETCLASSDEFINITIONID", required = true)
    protected STANDARDENTITYID_Type assetclassdefinitionid;

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Obtient la valeur de la propriété assetclassdefinitionid.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getASSETCLASSDEFINITIONID() {
        return assetclassdefinitionid;
    }

    /**
     * Définit la valeur de la propriété assetclassdefinitionid.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setASSETCLASSDEFINITIONID(STANDARDENTITYID_Type value) {
        this.assetclassdefinitionid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/SERVICELIFEUSAGEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SERVICELIFEUSAGEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SERVICELIFEUSAGEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETCLASSDEFINITIONID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICELIFEUSAGEID_Type", propOrder = {
    "uomid",
    "assetclassdefinitionid"
})
public class SERVICELIFEUSAGEID_Type {

    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;
    @XmlElement(name = "ASSETCLASSDEFINITIONID", required = true)
    protected STANDARDENTITYID_Type assetclassdefinitionid;

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

    /**
     * Gets the value of the assetclassdefinitionid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getASSETCLASSDEFINITIONID() {
        return assetclassdefinitionid;
    }

    /**
     * Sets the value of the assetclassdefinitionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setASSETCLASSDEFINITIONID(STANDARDENTITYID_Type value) {
        this.assetclassdefinitionid = value;
    }

}
